package cn.fw.hermes.service.biz;

import cn.fw.common.cache.locker.DistributedLocker;
import cn.fw.hermes.common.constant.RedisKey;
import cn.fw.hermes.common.utils.im.RedisKeyUtil;
import cn.fw.hermes.domain.db.Account;
import cn.fw.hermes.domain.db.BusinessAccount;
import cn.fw.hermes.domain.enums.UserTypeEnum;
import cn.fw.hermes.service.data.AccountService;
import cn.fw.hermes.service.data.BusinessAccountService;

import java.util.Optional;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.tuple.Pair;
import org.redisson.api.RLock;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @Author: Chenery
 * @Date: 2021/2/1 17:39
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class BusinessAccountBizService {

    private final BusinessAccountService businessAccountService;
    private final StringRedisTemplate redisTemplate;
    private final DistributedLocker distributedLocker;
    private final AccountService accountService;

    /**
     * 缓存所有系统账户信息到redis
     * 账户表中userType为2的账户
     */
    public void cacheToRedis() {
        List<BusinessAccount> businessAccountList = businessAccountService
                .queryAllBusinessAccount();
        String key = RedisKey.SYS_ACCOUNT.getCode();
        if (businessAccountList.size() > 0) {
            String lockKey = businessAccountList.get(0).getUserId().toString() + "bAccount";
            Pair<Boolean, RLock> lock = distributedLocker.tryLock(RedisKeyUtil.getDistributedKey(lockKey), TimeUnit.SECONDS, 0, 5);
            if  (!Boolean.TRUE.equals(lock.getKey())) {
                return;
            }

            for (BusinessAccount bAccount : businessAccountList) {
                Optional<Account> optional = accountService.queryAccountById(bAccount.getUserId());
                optional.ifPresent(account -> redisTemplate.opsForHash().put(key, bAccount.getBusinessType().getValue().toString(), account.getIdentifierCode()));
            }
            log.info("缓存系统账户数据到redis成功");
        }

    }

    /**
     * 添加系统账户对象
     *
     * @param businessAccount 系统账户对象
     * @return 保存结果
     */
    public Boolean saveBusinessAccount(BusinessAccount businessAccount) {
        return businessAccountService.saveBusinessAccountAccount(businessAccount);
    }


}
